"""Programmatic CRUD for AI project knowledge bases (Claude Projects, Gemini Gems)."""

from aikb.base import (
    KnowledgeFiles,
    KnowledgeBaseProvider,
    LocalFilesProvider,
    ClaudeProjectsProvider,
    LocalFiles,
    ClaudeProject,
    KnowledgeMall,
)
